<?php

declare(strict_types=1);

final class UserDeleteController extends AbstractController
{
	protected string $route = '/api/v1/user/{userId}';

	private int $userId;

	public function __construct(string $url)
	{
		parent::__construct($url);

		$this->userId = (int)$this->getUrlParamInt('userId');
	}

	public function handle(): void
	{
		parent::handle();

		if ($this->response->getStatus() !== ServerStatus::OK) {
			return;
		}

		try {
			$user = new User($this->userId);
			$user->Delete();

			$this->response = new ApiJsonResponse();
			$this->response->setParameter('success', true);
		} catch (Throwable $e) {
			$this->response = new ApiJsonResponse(ServerStatus::BAD_REQUEST);
			$this->response->setParameter('success', false);
			$this->response->setMessage($e->getMessage());
		}
	}
}